import { faAngleDoubleLeft, faAngleDoubleRight, faAngleLeft, faAngleRight } from "@fortawesome/free-solid-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import classNames from "classnames";
import React from "react";
import clamp from "lodash-es/clamp";
import { getLocal } from "./local";
// 大于等于多少页时显示省略符号
var MaxEllipsisNumber = 7;
// 省略号相隔边界多个少元素
var EllipsisBoundDist = 2;
function Pager(props) {
    var _a, _b;
    var _c = props.prefixCls, prefixCls = _c === void 0 ? "xy-page" : _c, _d = props.current, current = _d === void 0 ? 1 : _d, _e = props.pageCount, pageCount = _e === void 0 ? 0 : _e, onChange = props.onChange, itemRender = props.itemRender;
    function jump(page) {
        var num = clamp(page, 1, pageCount);
        if (onChange) {
            onChange(num);
        }
    }
    function getPages() {
        var showPrevMore = false;
        var showNextMore = false;
        var array = [];
        if (pageCount === 0) {
            return [1];
        }
        // 总页数大于 MaxEllipsisNumber 则可以显示省略
        if (pageCount > MaxEllipsisNumber) {
            if (current > MaxEllipsisNumber - EllipsisBoundDist) {
                showPrevMore = true;
            }
            if (current < pageCount - EllipsisBoundDist) {
                showNextMore = true;
            }
        }
        if (showPrevMore && !showNextMore) {
            var startPage = pageCount - (MaxEllipsisNumber - EllipsisBoundDist);
            for (var i = startPage; i < pageCount; ++i) {
                array.push(i);
            }
        }
        else if (!showPrevMore && showNextMore) {
            for (var i = EllipsisBoundDist; i < MaxEllipsisNumber; ++i) {
                array.push(i);
            }
        }
        else if (showPrevMore && showNextMore) {
            var offset = Math.floor(MaxEllipsisNumber / EllipsisBoundDist) - 1;
            for (var i = current - offset; i <= current + offset; ++i) {
                array.push(i);
            }
        }
        else {
            for (var i = EllipsisBoundDist; i < pageCount; ++i) {
                array.push(i);
            }
        }
        return array;
    }
    function createPageItem(current, type, content) {
        if (itemRender) {
            return itemRender(current, type, content);
        }
        else {
            return content;
        }
    }
    function firstPageItem() {
        var _a;
        if (pageCount >= 1) {
            return (React.createElement("li", { className: classNames(prefixCls + "-item", (_a = {}, _a[prefixCls + "-active"] = current === 1, _a)), onClick: function () { return jump(1); }, title: "1" }, createPageItem(1, "page", React.createElement("a", null, "1"))));
        }
        else {
            return null;
        }
    }
    function lastPageItem() {
        var _a;
        if (pageCount > 1) {
            return (React.createElement("li", { className: classNames(prefixCls + "-item", (_a = {}, _a[prefixCls + "-active"] = current === pageCount, _a)), onClick: function () { return jump(pageCount); }, title: "" + pageCount }, createPageItem(pageCount, "page", React.createElement("a", null, pageCount))));
        }
        else {
            return null;
        }
    }
    function prevMoreItem() {
        if (pageCount > MaxEllipsisNumber && current > MaxEllipsisNumber - EllipsisBoundDist) {
            return (React.createElement("li", { className: prefixCls + "-more", title: getLocal().Pagination.stridePrev, onClick: function () { return jump(current - 5); } },
                React.createElement("a", null,
                    React.createElement("div", { className: prefixCls + "-item-container" },
                        React.createElement(FontAwesomeIcon, { icon: faAngleDoubleLeft }),
                        React.createElement("span", { className: prefixCls + "-item-ellipsis" }, "\u2022\u2022\u2022")))));
        }
        else {
            return null;
        }
    }
    function nextMoreItem() {
        if (pageCount > MaxEllipsisNumber && current < pageCount - EllipsisBoundDist) {
            return (React.createElement("li", { className: prefixCls + "-more", title: getLocal().Pagination.trideNext, onClick: function () { return jump(current + 5); } },
                React.createElement("a", null,
                    React.createElement("div", { className: prefixCls + "-item-container" },
                        React.createElement(FontAwesomeIcon, { icon: faAngleDoubleRight }),
                        React.createElement("span", { className: prefixCls + "-item-ellipsis" }, "\u2022\u2022\u2022")))));
        }
        else {
            return null;
        }
    }
    return (React.createElement("ul", { className: prefixCls + "-pager" },
        React.createElement("li", { className: classNames(prefixCls + "-prev", (_a = {}, _a[prefixCls + "-disabled"] = current <= 1, _a)), onClick: function () { return jump(current - 1); }, title: getLocal().Pagination.prev }, createPageItem(null, "prev", React.createElement("a", { className: prefixCls + "-item-link" },
            React.createElement(FontAwesomeIcon, { icon: faAngleLeft })))),
        firstPageItem(),
        prevMoreItem(),
        getPages().map(function (page) {
            var _a;
            return (React.createElement("li", { key: page, onClick: function () { return jump(page); }, className: classNames(prefixCls + "-item", (_a = {}, _a[prefixCls + "-active"] = current === page, _a)), title: page }, createPageItem(page, "page", React.createElement("a", null, page))));
        }),
        nextMoreItem(),
        lastPageItem(),
        React.createElement("li", { className: classNames(prefixCls + "-next", (_b = {}, _b[prefixCls + "-disabled"] = current >= pageCount, _b)), onClick: function () { return jump(current + 1); }, title: getLocal().Pagination.next }, createPageItem(null, "next", React.createElement("a", { className: prefixCls + "-item-link" },
            React.createElement(FontAwesomeIcon, { icon: faAngleRight }))))));
}
export default React.memo(Pager);
//# sourceMappingURL=Pager.js.map